@@ -6,11 +6,15 @@
 """SutekhGui.py: start the GUI"""
 
 
-import gtk
 import logging
 import sys
 import optparse
 import os
+# This is annoying, but needs to be set to before gtk is imported to
+# work with Ubuntu's later unity-gtk2-module approach to moving
+# menus around
+os.environ["UBUNTU_MENUPROXY"] = "0"
+import gtk
 import traceback
 from sqlobject import sqlhub, connectionForURI
 from sutekh.core.SutekhObjects import VersionTable, TABLE_LIST
