@@ -201,6 +201,7 @@ class Expansions(AbbreviationLookup):
         'Sabbat Wars': ['SW'],
         'Sword of Caine': ['SoC'],
         'Tenth Anniversary': ['Tenth'],
+        'The Unaligned': ['TU'],
         'Third Edition': ['Third'],
         'Twilight Rebellion': ['TR'],
         'VTES': [],
@@ -296,6 +297,8 @@ class Titles(AbbreviationLookup):
         'Independent with 3 votes': [],
         # Laibon Titles
         'Magaji': [],
+        # Anarch Titles
+        'Baron': [],
     }
 
     dVoteValues = {
@@ -311,6 +314,8 @@ class Titles(AbbreviationLookup):
             'Independent with 3 votes': 3,
             # Laibon Titles
             'Magaji': 2,
+            # Anarch Titles
+            'Baron': 2,
             }
 
     @classmethod
