@@ -6,9 +6,12 @@
 
 """gtk.TreeModel class the card set list."""
 
-import gtk, gobject
-from sutekh.core.SutekhObjects import PhysicalCardSet
+import gtk
+import gobject
+from sutekh.core.SutekhObjects import PhysicalCardSet, IPhysicalCardSet
 from sutekh.core.Filters import NullFilter
+from sutekh.gui.ConfigFile import CARDSET_LIST
+
 
 class CardSetManagementModel(gtk.TreeStore):
     # pylint: disable-msg=R0904
@@ -24,11 +27,12 @@ class CardSetManagementModel(gtk.TreeStore):
 
         self._oMainWin = oMainWindow
 
-        self._bApplyFilter = False # whether to apply the select filter
+        self._bApplyFilter = False  # whether to apply the select filter
         # additional filters for selecting from the list
         self._oSelectFilter = None
         self.oEmptyIter = None
-        self.set_sort_func(0, self.sort_column)
+
+        self._aExcludedSet = set()
 
     # pylint: disable-msg=W0212, C0103
     # W0212 - we explicitly allow access via these properties
@@ -38,6 +42,14 @@ class CardSetManagementModel(gtk.TreeStore):
     selectfilter = property(fget=lambda self: self._oSelectFilter,
             fset=lambda self, x: setattr(self, '_oSelectFilter', x))
 
+    frame_id = property(fget=lambda self: CARDSET_LIST,
+            doc="Frame ID of the card set list (for selecting profiles)")
+
+    # This isn't a card set id, but it's here to support profiles
+    # (see CardListModel)
+    cardset_id = property(fget=lambda self: CARDSET_LIST,
+            doc="Cardset ID of card set list (for selecting profiles)")
+
     # pylint: enable-msg=W0212, C0103
 
     # pylint: disable-msg=R0201
@@ -52,12 +64,57 @@ class CardSetManagementModel(gtk.TreeStore):
         return oFilter.select(PhysicalCardSet).distinct()
     # pylint: enable-msg=R0201
 
+    def _format_set(self, oSet):
+        """Format the card set name for display"""
+        sMarkup = gobject.markup_escape_text(oSet.name)
+        if oSet.name in self._aExcludedSet:
+            sMarkup = '<span foreground="grey">%s</span>' % sMarkup
+        elif hasattr(self._oMainWin, 'find_cs_pane_by_set_name') and \
+                self._oMainWin.find_cs_pane_by_set_name(oSet.name):
+            sMarkup = '<span foreground="blue">%s</span>' % sMarkup
+        if oSet.inuse:
+            # In use sets are in bold
+            sMarkup = '<b>%s</b>' % sMarkup
+        return sMarkup
+
+    def exclude_set(self, sSetName):
+        """Mark the given set as excluded"""
+        self._aExcludedSet.add(sSetName)
+        # Update markup if required
+        oPath = self.get_path_from_name(sSetName)
+        if oPath:
+            oIter = self.get_iter(oPath)
+            sMarkup = self._format_set(IPhysicalCardSet(sSetName))
+            # gtk signals will do the rest for us
+            self.set(oIter, 0, sMarkup)
+
+    def unexclude_set(self, sSetName):
+        """Unmark the given set as excluded"""
+        self._aExcludedSet.discard(sSetName)
+
+    def is_excluded(self, sSetName):
+        """Check if this set is excluded"""
+        return sSetName in self._aExcludedSet
+
+    def enable_sorting(self):
+        """Enable the default sorting behaviour"""
+        # This is a method for consistency between the different models
+        # see CardListModel.py for more info
+        self.set_sort_func(0, self.sort_column)
+        # sort on card set name by default, for consistency elsewhere
+        self.set_sort_column_id(0, gtk.SORT_ASCENDING)
+
     def load(self):
         """Load the card sets into the card view"""
         self.clear()
         oCardSetIter = self.get_card_set_iterator(self.get_current_filter())
         self._dName2Iter = {}
 
+        # Disable sorting while we do the insertions - speeds things up
+        iSortColumn, iSortOrder = self.get_sort_column_id()
+        if iSortColumn is not None:
+            self.set_sort_column_id(-2, 0)
+
         # Loop through the card sets, getting the parent->child relationships
         for oCardSet in oCardSetIter:
             if oCardSet.name in self._dName2Iter:
@@ -67,25 +124,19 @@ class CardSetManagementModel(gtk.TreeStore):
                 # Do funky stuff to make sure parent is shown in the view
                 oParent = oCardSet
                 aToAdd = []
+                oIter = None
                 while oParent and oParent.name not in self._dName2Iter:
-                    aToAdd.insert(0, oParent) # Insert at the head
+                    aToAdd.insert(0, oParent)  # Insert at the head
                     oParent = oParent.parent
                 if oParent and oParent.name in self._dName2Iter:
                     oIter = self._dName2Iter[oParent.name]
-                else:
-                    oIter = None
             else:
                 # Just add
                 oIter = None
                 aToAdd = [oCardSet]
             for oSet in aToAdd:
                 oIter = self.append(oIter)
-                sMarkup = gobject.markup_escape_text(oSet.name)
-                if self._oMainWin.find_pane_by_name(oSet.name):
-                    sMarkup = '<span foreground="blue">%s</span>' % sMarkup
-                if oSet.inuse:
-                    # In use sets are in bold
-                    sMarkup = '<b>%s</b>' % sMarkup
+                sMarkup = self._format_set(oSet)
                 self.set(oIter, 0, sMarkup, 1, oSet.name)
                 self._dName2Iter[oSet.name] = oIter
 
@@ -95,6 +146,9 @@ class CardSetManagementModel(gtk.TreeStore):
             sText = self._get_empty_text()
             self.set(self.oEmptyIter, 0, sText)
 
+        if iSortColumn is not None:
+            self.set_sort_column_id(iSortColumn, iSortOrder)
+
     def get_current_filter(self):
         """Get the current applied filter."""
         if self.applyfilter:
@@ -140,9 +194,7 @@ class CardSetManagementModel(gtk.TreeStore):
         oIter = self.get_iter(oPath)
         return self.get_name_from_iter(oIter)
 
-    # pylint: disable-msg=W0613
-    # oModel required by function signature
-    def sort_column(self, oModel, oIter1, oIter2):
+    def sort_column(self, _oModel, oIter1, oIter2):
         """Custom sort function - ensure that markup doesn't affect sort
            order"""
         oCardSet1 = self.get_name_from_iter(oIter1)
