@@ -236,6 +236,21 @@ class ZipFileWrapper(object):
         self.__close_zip()
         return oHolder
 
+    def get_info_file(self, sFileName):
+        """Try to find a non-deck file in the zipfile.
+
+           Return None if it's not present, otherwise return
+           the contents."""
+        self.__open_zip_for_read()
+        sData = None
+        for oItem in self.oZip.infolist():
+            if oItem.filename == sFileName:
+                # First match found wins
+                sData = self.oZip.read(oItem.filename)
+                break
+        self.__close_zip()
+        return sData
+
     def get_warnings(self):
         """Get any warnings from the process"""
         return self._aWarnings
