@@ -6,14 +6,17 @@
 
 """Test database upgrading"""
 
-from sutekh.tests.TestCore import SutekhTest
+import sys
+from sutekh.tests.TestCore import SutekhTest, make_null_handler
+from sutekh.tests import create_db
 from sutekh.core.DatabaseUpgrade import copy_to_new_abstract_card_db, \
                                         create_final_copy
 from sutekh.core.CardLookup import SimpleLookup
 from sutekh.core.SutekhObjects import AbstractCard, PhysicalCardSet, \
-    IAbstractCard, IPhysicalCard, IExpansion, IPhysicalCardSet
+    AbstractCardAdapter, PhysicalCardAdapter, ExpansionAdapter, \
+    IPhysicalCardSet
 from sqlobject import sqlhub, connectionForURI
-from logging import FileHandler
+
 
 class DatabaseUpgradeTests(SutekhTest):
     """Class for the database upgrade tests."""
@@ -31,7 +34,8 @@ class DatabaseUpgradeTests(SutekhTest):
         # pylint: disable-msg=E1101
         # SQLObject confuses pylint
 
-        oPC = IPhysicalCard((IAbstractCard(".44 magnum"), IExpansion("Jyhad")))
+        oPC = PhysicalCardAdapter((AbstractCardAdapter(".44 magnum"),
+            ExpansionAdapter("Jyhad")))
         oMyCollection.addPhysicalCard(oPC)
 
         assert list(PhysicalCardSet.select())
@@ -41,15 +45,19 @@ class DatabaseUpgradeTests(SutekhTest):
         oOrigConn = sqlhub.processConnection
 
         sDbFile = self._create_tmp_file()
-        oNewConn = connectionForURI("sqlite://%s" % sDbFile)
+        # windows is different, since we don't have a starting / for the path
+        if sys.platform.startswith("win"):
+            oNewConn = connectionForURI("sqlite:///%s" % sDbFile)
+        else:
+            oNewConn = connectionForURI("sqlite://%s" % sDbFile)
         sqlhub.processConnection = oNewConn
 
-        self._setUpDb()
+        create_db()
 
         assert list(AbstractCard.select())
 
         oCardLookup = SimpleLookup()
-        oLogHandler = FileHandler('/dev/null')
+        oLogHandler = make_null_handler()
 
         copy_to_new_abstract_card_db(oOrigConn, oNewConn, oCardLookup,
                 oLogHandler)
@@ -58,9 +66,7 @@ class DatabaseUpgradeTests(SutekhTest):
         assert list(PhysicalCardSet.select())
 
         sqlhub.processConnection = oOrigConn
-        # pylint: disable-msg=W0612
-        # we aren't interested in aMsgs here
-        bResult, aMsgs = create_final_copy(oNewConn, oLogHandler)
+        bResult, _aMsgs = create_final_copy(oNewConn, oLogHandler)
 
         # Check
         self.failUnless(bResult)
@@ -68,7 +74,7 @@ class DatabaseUpgradeTests(SutekhTest):
         assert list(AbstractCard.select())
         assert list(PhysicalCardSet.select())
 
-        oMagnum = IAbstractCard('.44 magnum')
+        oMagnum = AbstractCardAdapter('.44 magnum')
         assert oMagnum
 
         oMyCollection = IPhysicalCardSet("My Collection")
@@ -78,3 +84,4 @@ class DatabaseUpgradeTests(SutekhTest):
 
         oPCS1 = IPhysicalCardSet("PCS1")
         assert oPCS1.parent == oMyCollection
+        oNewConn.close()
