@@ -7,9 +7,8 @@
 """Test Writing a card set to an ARDB deck XML file"""
 
 from sutekh.tests.TestCore import SutekhTest
-from sutekh.tests.core.test_PhysicalCardSet import aCardSetNames, \
-        get_phys_cards
-from sutekh.core.SutekhObjects import PhysicalCardSet
+from sutekh.tests.core.test_PhysicalCardSet import make_set_1
+from sutekh.core.CardSetHolder import CardSetWrapper
 from sutekh.io.WriteArdbXML import WriteArdbXML
 from sutekh.SutekhInfo import SutekhInfo
 import unittest
@@ -18,12 +17,12 @@ import time
 # pylint: disable-msg=W0511, C0301
 # W0511 - this is not a actual TODO item
 # C0301 - Ignore line length limits for this string
-sExpected = """<deck databaseVersion="%s" formatVersion="-TODO-1.0" generator="Sutekh [ %s ]">
+EXPECTED_1 = """<deck databaseVersion="%s" formatVersion="-TODO-1.0" generator="Sutekh [ %s ]">
+  <date>DATE</date>
   <name>Test Set 1</name>
   <author>A test author</author>
   <description>A test comment</description>
-  <date>%s</date>
-  <crypt avg="5.00" max="6" min="4" size="2">
+  <crypt avg="5.00" max="7" min="3" size="4">
     <vampire count="1" databaseID="11">
       <adv />
       <name>Abebe</name>
@@ -33,8 +32,8 @@ sExpected = """<deck databaseVersion="%s" formatVersion="-TODO-1.0" generator="S
       <capacity>4</capacity>
       <group>4</group>
       <text>Independent.</text>
-    </vampire><vampire count="1" databaseID="19">
-      <adv>(Advanced)</adv>
+    </vampire><vampire count="1" databaseID="20">
+      <adv>Advanced</adv>
       <name>Alan Sovereign</name>
       <set>Promo20051001</set>
       <disciplines>AUS DOM for pre</disciplines>
@@ -43,29 +42,54 @@ sExpected = """<deck databaseVersion="%s" formatVersion="-TODO-1.0" generator="S
       <group>3</group>
       <text>Advanced, Camarilla: While Alan is ready, you may pay some or all of the pool cost of equipping from any investment cards you control.
 [MERGED] During your master phase, if Alan is ready, you may move a counter from any investment card to your pool.</text>
+    </vampire><vampire count="1" databaseID="42">
+      <adv />
+      <name>Inez "Nurse216" Villagrande</name>
+      <set>NoR</set>
+      <disciplines>inn</disciplines>
+      <clan>Imbued</clan>
+      <capacity>3</capacity>
+      <group>4</group>
+      <text>When Inez enters play, you may search your library (shuffle afterward) or hand for a power that requires innocence and put it on her.</text>
+    </vampire><vampire count="1" databaseID="63">
+      <adv />
+      <name>Siamese, The</name>
+      <set>BL</set>
+      <disciplines>PRE SPI ani pro</disciplines>
+      <clan>Ahrimane</clan>
+      <capacity>7</capacity>
+      <group>2</group>
+      <text>Sabbat: +1 bleed. Sterile.</text>
     </vampire>
-  </crypt><library size="9">
+  </crypt><library size="13">
     <card count="1" databaseID="1">
       <name>.44 Magnum</name>
       <set>Jyhad</set>
-      <cost>2 pool </cost>
+      <cost>2 pool</cost>
       <type>Equipment</type>
       <text>Weapon, gun.
 2R damage each strike, with an optional maneuver each combat.</text>
-    </card><card count="1" databaseID="1">
+    </card><card count="3" databaseID="1">
       <name>.44 Magnum</name>
       <set>CE</set>
-      <cost>2 pool </cost>
+      <cost>2 pool</cost>
       <type>Equipment</type>
       <text>Weapon, gun.
 2R damage each strike, with an optional maneuver each combat.</text>
     </card><card count="2" databaseID="2">
       <name>AK-47</name>
       <set>LotN</set>
-      <cost>5 pool </cost>
+      <cost>5 pool</cost>
       <type>Equipment</type>
       <text>Weapon. Gun.
 2R damage each strike, with an optional maneuver {each combat}. When bearer strikes with this gun, he or she gets an optional additional strike this round, only usable to strike with this gun.</text>
+    </card><card count="1" databaseID="6">
+      <name>Aaron's Feeding Razor</name>
+      <set>KoT</set>
+      <cost>1 pool</cost>
+      <type>Equipment</type>
+      <text>Unique equipment.
+When this vampire successfully hunts, he or she gains 1 additional blood.</text>
     </card><card count="2" databaseID="8">
       <name>Abbot</name>
       <set>Third</set>
@@ -78,53 +102,43 @@ Put this card on this acting Sabbat vampire and untap him or her. This Sabbat va
       <type>Master</type>
       <text>Master: Discipline. Trifle.
 Put this card on a Laibon or on a vampire with Protean [pro]. This vampire gains one level of Abombwe [abo]. Capacity increases by 1: the vampire is one generation older. Cannot be placed on a vampire with superior Abombwe.</text>
-    </card><card count="1" databaseID="37">
+    </card><card count="1" databaseID="60">
+      <name>Scapelli, The Family "Mechanic"</name>
+      <set>DS</set>
+      <cost>3 pool</cost>
+      <requirement>Giovanni</requirement>
+      <type>Ally</type>
+      <text>Unique {mortal} with 3 life. {0 strength}, 1 bleed.
+{Scapelli may strike for 2R damage.} Once each combat, Scapelli may press to continue combat.</text>
+    </card><card count="1" databaseID="52">
       <name>Path of Blood, The</name>
       <set>LotN</set>
-      <cost>1 pool </cost>
+      <cost>1 pool</cost>
       <requirement>Assamite</requirement>
       <type>Master</type>
       <text>Unique master.
-Put this card in play. Cards that require Quietus [qui] cost Assamites 1 less blood. Any minion may burn this card as a (D) action; if that minion is a vampire, he or she then takes 1 unpreventable damage when this card is burned.</text>
+Put this card in play. Cards that require Quietus [qui] {cost Assamites 1 less blood}. Any minion may burn this card as a (D) action; if that minion is a vampire, he or she then takes 1 unpreventable damage when this card is burned.</text>
     </card>
   </library>
-</deck>""" % (WriteArdbXML.sDatabaseVersion, SutekhInfo.VERSION_STR,
-        time.strftime('%Y-%m-%d', time.localtime()))
+</deck>""" % (WriteArdbXML.sDatabaseVersion, SutekhInfo.VERSION_STR)
 # pylint: enable-msg=W0511, C0301
 
+
 class ArdbXMLWriterTests(SutekhTest):
     """class for the ARDB deck XML writer tests"""
 
     def test_deck_writer(self):
         """Test ARDB XML deck writing"""
-        # pylint: disable-msg=E1101, R0915, R0914
-        # E1101: SQLObject + PyProtocols magic confuses pylint
-        # R0915, R0914: Want a long, sequential test case to minimise
-        # repeated setups, so it has lots of lines + variables
-        aAddedPhysCards = get_phys_cards()
-        # We have a physical card list, so create some physical card sets
-        oPhysCardSet1 = PhysicalCardSet(name=aCardSetNames[0])
-        oPhysCardSet1.comment = 'A test comment'
-        oPhysCardSet1.author = 'A test author'
-
-        for oCard in aAddedPhysCards:
-            oPhysCardSet1.addPhysicalCard(oCard.id)
-            oPhysCardSet1.syncUpdate()
+        oPhysCardSet1 = make_set_1()
+        sCurDate = time.strftime('>%Y-%m-%d<', time.localtime())
 
         # Check output
 
         oWriter = WriteArdbXML()
-        sTempFileName =  self._create_tmp_file()
-        fOut = open(sTempFileName, 'w')
-        oWriter.write(fOut, oPhysCardSet1.name, oPhysCardSet1.author,
-                oPhysCardSet1.comment, oPhysCardSet1.cards)
-        fOut.close()
+        sData = self._round_trip_obj(oWriter, CardSetWrapper(oPhysCardSet1))
+        sData = sData.replace(sCurDate, '>DATE<')
 
-        fIn = open(sTempFileName, 'rU')
-        sData = fIn.read()
-        fIn.close()
-
-        self.assertEqual(sData, sExpected)
+        self.assertEqual(sData, EXPECTED_1)
 
 if __name__ == "__main__":
     unittest.main()
